aboutsummaryrefslogtreecommitdiff
path: root/classes/IsisDb.php
diff options
context:
space:
mode:
Diffstat (limited to 'classes/IsisDb.php')
-rw-r--r--classes/IsisDb.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/classes/IsisDb.php b/classes/IsisDb.php
index 43a51dc..4a2218a 100644
--- a/classes/IsisDb.php
+++ b/classes/IsisDb.php
@@ -24,17 +24,17 @@ interface IsisDb {
* Read an entry from the database.
*
* @param $id
- * Database row id.
+ * Database entry id.
*/
public function read($id);
/**
* Return number of rows in the database.
*
* @return
* Number of rows in the database.
*/
- public function rows();
+ public function entries();
/**
* Return an example database schema.
@@ -24,17 +24,17 @@ interface IsisDb {
public function read($id);
/**
- * Return number of rows in the database.
+ * Return number of entries in the database.
*
* @return
@@ -24,17 +24,17 @@ interface IsisDb {
*
* @return
- * Number of rows in the database.
+ * Number of entries in the database.
*/